@@ -28,7 +28,7 @@ has 'facets' => (
     coerce => $facets_type->coercion,
 );
 has 'fields' => ( is => 'rw', isa => Maybe [ArrayRef], );
-has 'link' => ( is => 'rw', isa => Str, builder => 'init_string' );
+has 'link' => ( is => 'rw', isa => Str, builder => 'init_link' );
 has 'cache' => ( is => 'rw', isa => Maybe [Object], builder => 'init_cache' );
 has 'cache_ttl' => ( is => 'rw', isa => Int,  default => sub { 60 * 60 } );
 has 'cache_ok'  => ( is => 'rw', isa => Bool, default => sub {1} );
@@ -40,6 +40,12 @@ has 'searcher' => (
     lazy    => 1,
     builder => 'init_searcher'
 );
+has 'indexer' => (
+    is      => 'rw',
+    isa     => Maybe [Object],
+    lazy    => 1,
+    builder => 'init_indexer'
+);
 has 'suggester' => (
     is      => 'rw',
     isa     => Maybe [Object],
@@ -100,7 +106,7 @@ has 'default_response_format' => (
 has 'cache_key_seed' =>
     ( is => 'rw', isa => Maybe [Str], builder => 'init_cache_key_seed' );
 
-our $VERSION = '0.399_02';
+our $VERSION = '0.399_03';
 
 sub BUILD {
     my $self = shift;
@@ -149,7 +155,9 @@ sub init_suggester_config {
     return {};
 }
 
+sub init_link     {''}
 sub init_searcher { confess "$_[0] does not implement init_searcher()" }
+sub init_indexer  { confess "$_[0] does not implement init_indexer()" }
 sub type          { confess "$_[0] does not implement type()" }
 sub has_rest_api  {0}
 
